<!--
SPDX-FileCopyrightText: 2025 Florian Obersteiner / KIT
SPDX-FileContributor: Florian Obersteiner <f.obersteiner@kit.edu>

SPDX-License-Identifier: CC-BY-SA-4.0
-->

[![License: LGPL v3](https://img.shields.io/badge/License-LGPL%20v3-blue.svg)](https://www.gnu.org/licenses/lgpl-3.0)
![test coverage](https://gitlab.kit.edu/FObersteiner/pyfuppes/badges/main/coverage.svg?job=coverage)
[![on PyPI](https://badge.fury.io/py/pyfuppes.svg)](https://badge.fury.io/py/pyfuppes)

# pyFuppes

A collection of tools in Python, mostly revolving around time series data analysis. Caution: this package is pretty dependency-heavy.

## License

`LGPLv3` - see LICENSE file in the root directory of the repository.
